# Generated by roxygen2: do not edit by hand

export(combine_summary)
export(descide)
export(plot_clustering)
export(plot_connectivity_precedence)
export(plot_heatmap)
export(plot_string_network)
export(rank_search_results)
export(search_pubmed)
export(search_string_db)
export(single_pubmed_search)
importFrom(ComplexHeatmap,Heatmap)
importFrom(ComplexHeatmap,HeatmapList)
importFrom(ComplexHeatmap,draw)
importFrom(STRINGdb,STRINGdb)
importFrom(circlize,colorRamp2)
importFrom(data.table,data.table)
importFrom(dplyr,across)
importFrom(dplyr,all_of)
importFrom(dplyr,arrange)
importFrom(dplyr,case_when)
importFrom(dplyr,desc)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,row_number)
importFrom(dplyr,select)
importFrom(dplyr,slice)
importFrom(dplyr,summarise)
importFrom(ggplot2,aes)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_line)
importFrom(ggplot2,element_rect)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_minimal)
importFrom(ggrepel,geom_text_repel)
importFrom(grDevices,dev.off)
importFrom(grDevices,pdf)
importFrom(grDevices,png)
importFrom(grid,gpar)
importFrom(igraph,components)
importFrom(igraph,graph_from_adjacency_matrix)
importFrom(magrittr,"%>%")
importFrom(openxlsx,addWorksheet)
importFrom(openxlsx,createWorkbook)
importFrom(openxlsx,saveWorkbook)
importFrom(openxlsx,writeData)
importFrom(rentrez,entrez_search)
importFrom(stats,setNames)
importFrom(tibble,column_to_rownames)
importFrom(tidyr,pivot_wider)
importFrom(utils,head)
importFrom(utils,str)
importFrom(utils,write.csv)
importFrom(utils,write.table)
